pub enum ProblemAction {
New {
title: String,
priority: String,
parent: Option<String>,
milestone: Option<String>,
force: bool,
tags: Vec<String>,
},
List {
status: Option<String>,
tree: bool,
milestone: Option<String>,
search: Option<String>,
assignee: Option<String>,
tag: Option<String>,
sort: String,
json: bool,
},
Show {
problem_id: String,
json: bool,
},
Edit {
problem_id: String,
title: Option<String>,
status: Option<String>,
priority: Option<String>,
parent: Option<String>,
add_tag: Option<String>,
remove_tag: Option<String>,
set_tags: Option<Vec<String>>,
},
Tree {
problem_id: Option<String>,
},
Solve {
problem_id: String,
github_close: bool,
},
Dissolve {
problem_id: String,
reason: Option<String>,
github_close: bool,
},
Assign {
problem_id: String,
to: Option<String>,
},
Reopen {
problem_id: String,
},
Duplicate {
problem_id: String,
of: String,
},
Graph {
milestone: Option<String>,
all: bool,
},
}Variants
New
Create a new problem
Fields
Comma-separated tags (e.g., –tags backend,auth,size:L)
List
List problems with optional filters
Fields
Show
Show details for a problem
Fields
Edit
Edit a problem’s title, status, or priority
Fields
Replace all tags (comma-separated; empty string clears tags)
Tree
Show problems as a hierarchy tree
Solve
Mark a problem solved (requires an approved solution or all sub-problems solved)
Fields
Dissolve
Dissolve a problem — mark it as based on false premises, not truly a problem
Fields
Assign
Assign a problem to yourself or someone else
Fields
Reopen
Reopen a solved or dissolved problem (transition back to open)
Duplicate
Mark a problem as a duplicate of another — dissolves it with a back-reference
Fields
Graph
Render problem hierarchy as ASCII DAG